pub struct PrometheusSink { /* private fields */ }Expand description
Prometheus metrics sink for Rustvello.
Registers standard metrics and exposes them via an HTTP /metrics endpoint.
The sink spawns a background tokio task for the HTTP server.
Singleton: Only one PrometheusSink can be created per process because
the metrics crate uses a global recorder. A second call to [new] will
return an error.
Metric Naming Convention
rustvello_<subsystem>_<metric>_<unit>
Example
use rustvello_prometheus::PrometheusSink;
use std::net::SocketAddr;
let sink = PrometheusSink::new("0.0.0.0:9090".parse()?)?;Implementations
Sourceimpl PrometheusSink
impl PrometheusSink
Sourcepub fn new(bind: SocketAddr) -> RustvelloResult<Self>
pub fn new(bind: SocketAddr) -> RustvelloResult<Self>
Create a new Prometheus sink and start the HTTP exporter on the given address.
Errors
Returns an error if the global metrics recorder has already been installed
(only one PrometheusSink per process).